@@ -82,7 +82,7 @@ besf_vc		<- function( y, x = NULL, xconst = NULL, coords, method = "reml", penal
 
     m[-(1:nx)]		<- m[ -( 1:nx ) ] * evSqrt
     test			<-try(Minv	<- solve( M, tol = 1e-30 ))
-    if(class(test)=="try-error"){
+    if(class(test)[ 1 ] == "try-error"){
       loglik  	<- Inf
     } else {
       b		<- Minv %*% m
@@ -328,7 +328,7 @@ besf_vc		<- function( y, x = NULL, xconst = NULL, coords, method = "reml", penal
         try1	<- try( M0inv	<- solve( MM0,  tol = 1e-30 ), silent = TRUE )
         try2	<- try( Mdet0	<- Mdet_f0( M = MM, M0 = MM0, id = idd,
                                        par0_sel = par0_sel, emet = method ), silent = TRUE)
-        er_dum	<- ( class(try1) =="try-error" ) | ( class(try2) =="try-error" )
+        er_dum	<- ( class(try1)[1] =="try-error" ) | ( class(try2)[1] =="try-error" )
         if( er_dum == TRUE ){
           M	<- M [ id_omit1 == 0, id_omit1 == 0 ]
           M0	<- M0[ id_omit1 == 0, id_omit1 == 0 ]
