@@ -21,7 +21,7 @@ resf  	<- function( y, x = NULL, xgroup = NULL, meig, method = "reml" ){
     m[  -( 1:nx) ]			<- m[ -( 1:nx ) ] * evSqrt
 
     test    <-try( Minv	<- solve( M, tol = 1e-25 ) )
-    if( class( test ) == "try-error" ){
+    if( class( test )[1] == "try-error" ){
       loglik  <- Inf
     } else {
       b	<- Minv %*% m
